Class: Comet::GetSharedStorageQuotaResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/comet/models/get_shared_storage_quota_response.rb

Overview

GetSharedStorageQuotaResponse is a typed class wrapper around the underlying Comet Server API data structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeGetSharedStorageQuotaResponse

Returns a new instance of GetSharedStorageQuotaResponse.



35
36
37
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 35

def initialize
  clear
end

Instance Attribute Details

#current_usageObject

Bytes



30
31
32
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 30

def current_usage
  @current_usage
end

#messageObject

Returns the value of attribute message.



20
21
22
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 20

def message
  @message
end

#shared_storage_quotaObject

Returns the value of attribute shared_storage_quota.



23
24
25
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 23

def shared_storage_quota
  @shared_storage_quota
end

#shared_storage_quota_hashObject

Returns the value of attribute shared_storage_quota_hash.



26
27
28
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 26

def shared_storage_quota_hash
  @shared_storage_quota_hash
end

#statusObject

If the operation was successful, the status will be in the 200-299 range.



17
18
19
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 17

def status
  @status
end

#unknown_json_fieldsObject

Returns the value of attribute unknown_json_fields.



33
34
35
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 33

def unknown_json_fields
  @unknown_json_fields
end

Instance Method Details

#clearObject



39
40
41
42
43
44
45
46
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 39

def clear
  @status = 0
  @message = ''
  @shared_storage_quota = Comet::SharedStorageQuota.new
  @shared_storage_quota_hash = ''
  @current_usage = 0
  @unknown_json_fields = {}
end

#from_hash(obj) ⇒ Object

Parameters:

  • obj (Hash)

    The complete object as a Ruby hash

Raises:

  • (TypeError)


56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 56

def from_hash(obj)
  raise TypeError, "'obj' expected Hash, got #{obj.class}" unless obj.is_a? Hash

  obj.each do |k, v|
    case k
    when 'Status'
      raise TypeError, "'v' expected Numeric, got #{v.class}" unless v.is_a? Numeric

      @status = v
    when 'Message'
      raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String

      @message = v
    when 'SharedStorageQuota'
      @shared_storage_quota = Comet::SharedStorageQuota.new
      @shared_storage_quota.from_hash(v)
    when 'SharedStorageQuotaHash'
      raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String

      @shared_storage_quota_hash = v
    when 'CurrentUsage'
      raise TypeError, "'v' expected Numeric, got #{v.class}" unless v.is_a? Numeric

      @current_usage = v
    else
      @unknown_json_fields[k] = v
    end
  end
end

#from_json(json_string) ⇒ Object

Parameters:

  • json_string (String)

    The complete object in JSON format

Raises:

  • (TypeError)


49
50
51
52
53
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 49

def from_json(json_string)
  raise TypeError, "'json_string' expected String, got #{json_string.class}" unless json_string.is_a? String

  from_hash(JSON.parse(json_string))
end

#to_hHash

Returns The complete object as a Ruby hash.

Returns:

  • (Hash)

    The complete object as a Ruby hash



101
102
103
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 101

def to_h
  to_hash
end

#to_hashHash

Returns The complete object as a Ruby hash.

Returns:

  • (Hash)

    The complete object as a Ruby hash



87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 87

def to_hash
  ret = {}
  ret['Status'] = @status
  ret['Message'] = @message
  ret['SharedStorageQuota'] = @shared_storage_quota
  ret['SharedStorageQuotaHash'] = @shared_storage_quota_hash
  ret['CurrentUsage'] = @current_usage
  @unknown_json_fields.each do |k, v|
    ret[k] = v
  end
  ret
end

#to_json(options = {}) ⇒ String

Returns The complete object as a JSON string.

Returns:

  • (String)

    The complete object as a JSON string



106
107
108
# File 'lib/comet/models/get_shared_storage_quota_response.rb', line 106

def to_json(options = {})
  to_hash.to_json(options)
end