Class: Comet::PVEStorageName
- Inherits:
-
Object
- Object
- Comet::PVEStorageName
- Defined in:
- lib/comet/models/pvestorage_name.rb
Overview
PVEStorageName is a typed class wrapper around the underlying Comet Server API data structure. PVEStorageName contains the name and type of storage configured on a Proxmox Cluster
Instance Attribute Summary collapse
-
#content ⇒ Object
Returns the value of attribute content.
-
#name ⇒ Object
Returns the value of attribute name.
-
#type ⇒ Object
Returns the value of attribute type.
-
#unknown_json_fields ⇒ Object
Returns the value of attribute unknown_json_fields.
Instance Method Summary collapse
- #clear ⇒ Object
- #from_hash(obj) ⇒ Object
- #from_json(json_string) ⇒ Object
-
#initialize ⇒ PVEStorageName
constructor
A new instance of PVEStorageName.
-
#to_h ⇒ Hash
The complete object as a Ruby hash.
-
#to_hash ⇒ Hash
The complete object as a Ruby hash.
-
#to_json(options = {}) ⇒ String
The complete object as a JSON string.
Constructor Details
#initialize ⇒ PVEStorageName
Returns a new instance of PVEStorageName.
28 29 30 |
# File 'lib/comet/models/pvestorage_name.rb', line 28 def initialize clear end |
Instance Attribute Details
#content ⇒ Object
Returns the value of attribute content.
23 24 25 |
# File 'lib/comet/models/pvestorage_name.rb', line 23 def content @content end |
#name ⇒ Object
Returns the value of attribute name.
17 18 19 |
# File 'lib/comet/models/pvestorage_name.rb', line 17 def name @name end |
#type ⇒ Object
Returns the value of attribute type.
20 21 22 |
# File 'lib/comet/models/pvestorage_name.rb', line 20 def type @type end |
#unknown_json_fields ⇒ Object
Returns the value of attribute unknown_json_fields.
26 27 28 |
# File 'lib/comet/models/pvestorage_name.rb', line 26 def unknown_json_fields @unknown_json_fields end |
Instance Method Details
#clear ⇒ Object
32 33 34 35 36 37 |
# File 'lib/comet/models/pvestorage_name.rb', line 32 def clear @name = '' @type = '' @content = [] @unknown_json_fields = {} end |
#from_hash(obj) ⇒ Object
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/comet/models/pvestorage_name.rb', line 47 def from_hash(obj) raise TypeError, "'obj' expected Hash, got #{obj.class}" unless obj.is_a? Hash obj.each do |k, v| case k when 'Name' raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String @name = v when 'Type' raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String @type = v when 'Content' if v.nil? @content = [] else @content = Array.new(v.length) v.each_with_index do |v1, i1| raise TypeError, "'v1' expected String, got #{v1.class}" unless v1.is_a? String @content[i1] = v1 end end else @unknown_json_fields[k] = v end end end |
#from_json(json_string) ⇒ Object
40 41 42 43 44 |
# File 'lib/comet/models/pvestorage_name.rb', line 40 def from_json(json_string) raise TypeError, "'json_string' expected String, got #{json_string.class}" unless json_string.is_a? String from_hash(JSON.parse(json_string)) end |
#to_h ⇒ Hash
Returns The complete object as a Ruby hash.
90 91 92 |
# File 'lib/comet/models/pvestorage_name.rb', line 90 def to_h to_hash end |
#to_hash ⇒ Hash
Returns The complete object as a Ruby hash.
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/comet/models/pvestorage_name.rb', line 78 def to_hash ret = {} ret['Name'] = @name ret['Type'] = @type ret['Content'] = @content @unknown_json_fields.each do |k, v| ret[k] = v end ret end |
#to_json(options = {}) ⇒ String
Returns The complete object as a JSON string.
95 96 97 |
# File 'lib/comet/models/pvestorage_name.rb', line 95 def to_json( = {}) to_hash.to_json() end |