Class: Comet::ProtectedItemWithBackupRulesResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/comet/models/protected_item_with_backup_rules_response.rb

Overview

ProtectedItemWithBackupRulesResponse is a typed class wrapper around the underlying Comet Server API data structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeProtectedItemWithBackupRulesResponse

Returns a new instance of ProtectedItemWithBackupRulesResponse.



36
37
38
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 36

def initialize
  clear
end

Instance Attribute Details

#backup_rulesObject

All backup rules for the Protected Item



28
29
30
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 28

def backup_rules
  @backup_rules
end

#messageObject

Returns the value of attribute message.



20
21
22
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 20

def message
  @message
end

#profile_hashObject

Returns the value of attribute profile_hash.



31
32
33
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 31

def profile_hash
  @profile_hash
end

#sourceObject

The Protected Item configuration



24
25
26
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 24

def source
  @source
end

#statusObject

If the operation was successful, the status will be in the 200-299 range.



17
18
19
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 17

def status
  @status
end

#unknown_json_fieldsObject

Returns the value of attribute unknown_json_fields.



34
35
36
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 34

def unknown_json_fields
  @unknown_json_fields
end

Instance Method Details

#clearObject



40
41
42
43
44
45
46
47
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 40

def clear
  @status = 0
  @message = ''
  @source = Comet::SourceConfig.new
  @backup_rules = {}
  @profile_hash = ''
  @unknown_json_fields = {}
end

#from_hash(obj) ⇒ Object

Parameters:

  • obj (Hash)

    The complete object as a Ruby hash

Raises:

  • (TypeError)


57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 57

def from_hash(obj)
  raise TypeError, "'obj' expected Hash, got #{obj.class}" unless obj.is_a? Hash

  obj.each do |k, v|
    case k
    when 'Status'
      raise TypeError, "'v' expected Numeric, got #{v.class}" unless v.is_a? Numeric

      @status = v
    when 'Message'
      raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String

      @message = v
    when 'Source'
      @source = Comet::SourceConfig.new
      @source.from_hash(v)
    when 'BackupRules'
      @backup_rules = {}
      if v.nil?
        @backup_rules = {}
      else
        v.each do |k1, v1|
          @backup_rules[k1] = Comet::BackupRuleConfig.new
          @backup_rules[k1].from_hash(v1)
        end
      end
    when 'ProfileHash'
      raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String

      @profile_hash = v
    else
      @unknown_json_fields[k] = v
    end
  end
end

#from_json(json_string) ⇒ Object

Parameters:

  • json_string (String)

    The complete object in JSON format

Raises:

  • (TypeError)


50
51
52
53
54
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 50

def from_json(json_string)
  raise TypeError, "'json_string' expected String, got #{json_string.class}" unless json_string.is_a? String

  from_hash(JSON.parse(json_string))
end

#to_hHash

Returns The complete object as a Ruby hash.

Returns:

  • (Hash)

    The complete object as a Ruby hash



110
111
112
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 110

def to_h
  to_hash
end

#to_hashHash

Returns The complete object as a Ruby hash.

Returns:

  • (Hash)

    The complete object as a Ruby hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 94

def to_hash
  ret = {}
  ret['Status'] = @status
  ret['Message'] = @message
  ret['Source'] = @source
  unless @backup_rules.nil?
    ret['BackupRules'] = @backup_rules
  end
  ret['ProfileHash'] = @profile_hash
  @unknown_json_fields.each do |k, v|
    ret[k] = v
  end
  ret
end

#to_json(options = {}) ⇒ String

Returns The complete object as a JSON string.

Returns:

  • (String)

    The complete object as a JSON string



115
116
117
# File 'lib/comet/models/protected_item_with_backup_rules_response.rb', line 115

def to_json(options = {})
  to_hash.to_json(options)
end