Class: Comet::PVEVM
- Inherits:
-
Object
- Object
- Comet::PVEVM
- Defined in:
- lib/comet/models/pvevm.rb
Overview
PVEVM is a typed class wrapper around the underlying Comet Server API data structure. PVEVM describes a single Proxmox virtual machine or container.
Instance Attribute Summary collapse
-
#cpu ⇒ Object
Returns the value of attribute cpu.
-
#disks ⇒ Object
Returns the value of attribute disks.
-
#memory ⇒ Object
Returns the value of attribute memory.
-
#name ⇒ Object
Returns the value of attribute name.
-
#node ⇒ Object
Returns the value of attribute node.
-
#ostype ⇒ Object
Returns the value of attribute ostype.
-
#running ⇒ Object
Returns the value of attribute running.
-
#type ⇒ Object
Returns the value of attribute type.
-
#unknown_json_fields ⇒ Object
Returns the value of attribute unknown_json_fields.
-
#vmid ⇒ Object
String type, but always contains an integer value.
Instance Method Summary collapse
- #clear ⇒ Object
- #from_hash(obj) ⇒ Object
- #from_json(json_string) ⇒ Object
-
#initialize ⇒ PVEVM
constructor
A new instance of PVEVM.
-
#to_h ⇒ Hash
The complete object as a Ruby hash.
-
#to_hash ⇒ Hash
The complete object as a Ruby hash.
-
#to_json(options = {}) ⇒ String
The complete object as a JSON string.
Constructor Details
#initialize ⇒ PVEVM
Returns a new instance of PVEVM.
47 48 49 |
# File 'lib/comet/models/pvevm.rb', line 47 def initialize clear end |
Instance Attribute Details
#cpu ⇒ Object
Returns the value of attribute cpu.
17 18 19 |
# File 'lib/comet/models/pvevm.rb', line 17 def cpu @cpu end |
#disks ⇒ Object
Returns the value of attribute disks.
20 21 22 |
# File 'lib/comet/models/pvevm.rb', line 20 def disks @disks end |
#memory ⇒ Object
Returns the value of attribute memory.
23 24 25 |
# File 'lib/comet/models/pvevm.rb', line 23 def memory @memory end |
#name ⇒ Object
Returns the value of attribute name.
26 27 28 |
# File 'lib/comet/models/pvevm.rb', line 26 def name @name end |
#node ⇒ Object
Returns the value of attribute node.
29 30 31 |
# File 'lib/comet/models/pvevm.rb', line 29 def node @node end |
#ostype ⇒ Object
Returns the value of attribute ostype.
32 33 34 |
# File 'lib/comet/models/pvevm.rb', line 32 def ostype @ostype end |
#running ⇒ Object
Returns the value of attribute running.
35 36 37 |
# File 'lib/comet/models/pvevm.rb', line 35 def running @running end |
#type ⇒ Object
Returns the value of attribute type.
38 39 40 |
# File 'lib/comet/models/pvevm.rb', line 38 def type @type end |
#unknown_json_fields ⇒ Object
Returns the value of attribute unknown_json_fields.
45 46 47 |
# File 'lib/comet/models/pvevm.rb', line 45 def unknown_json_fields @unknown_json_fields end |
#vmid ⇒ Object
String type, but always contains an integer value
42 43 44 |
# File 'lib/comet/models/pvevm.rb', line 42 def vmid @vmid end |
Instance Method Details
#clear ⇒ Object
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/comet/models/pvevm.rb', line 51 def clear @cpu = '' @disks = [] @memory = '' @name = '' @node = '' @ostype = '' @type = '' @vmid = '' @unknown_json_fields = {} end |
#from_hash(obj) ⇒ Object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/comet/models/pvevm.rb', line 71 def from_hash(obj) raise TypeError, "'obj' expected Hash, got #{obj.class}" unless obj.is_a? Hash obj.each do |k, v| case k when 'CPU' raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String @cpu = v when 'Disks' if v.nil? @disks = [] else @disks = Array.new(v.length) v.each_with_index do |v1, i1| @disks[i1] = Comet::PVEDisk.new @disks[i1].from_hash(v1) end end when 'Memory' raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String @memory = v when 'Name' raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String @name = v when 'Node' raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String @node = v when 'OSType' raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String @ostype = v when 'Running' @running = v when 'Type' raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String @type = v when 'VMID' raise TypeError, "'v' expected String, got #{v.class}" unless v.is_a? String @vmid = v else @unknown_json_fields[k] = v end end end |
#from_json(json_string) ⇒ Object
64 65 66 67 68 |
# File 'lib/comet/models/pvevm.rb', line 64 def from_json(json_string) raise TypeError, "'json_string' expected String, got #{json_string.class}" unless json_string.is_a? String from_hash(JSON.parse(json_string)) end |
#to_h ⇒ Hash
Returns The complete object as a Ruby hash.
141 142 143 |
# File 'lib/comet/models/pvevm.rb', line 141 def to_h to_hash end |
#to_hash ⇒ Hash
Returns The complete object as a Ruby hash.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/comet/models/pvevm.rb', line 123 def to_hash ret = {} ret['CPU'] = @cpu ret['Disks'] = @disks ret['Memory'] = @memory ret['Name'] = @name ret['Node'] = @node ret['OSType'] = @ostype ret['Running'] = @running ret['Type'] = @type ret['VMID'] = @vmid @unknown_json_fields.each do |k, v| ret[k] = v end ret end |
#to_json(options = {}) ⇒ String
Returns The complete object as a JSON string.
146 147 148 |
# File 'lib/comet/models/pvevm.rb', line 146 def to_json( = {}) to_hash.to_json() end |